@@ -100,7 +100,7 @@ class TaskRequestDTO(BaseModel):
     git_branch: Optional[str]
     task_type: Optional[str] = 'cluster'
     task_template: Optional[str] = None
-    task_env: Optional[str] = None
+    task_env: Optional[dict] = None
     task_command: Optional[List[str]] = ['sleep', '100000']
     task_arg: Optional[List[str]] = None
     task_working_dir: Optional[str] = None
