@@ -1,4 +1,5 @@
 import datetime
+from ipaddress import ip_address
 
 class ValueObject:
     def __init__(self, value=None):
@@ -167,3 +168,21 @@ class K3SNodeType(UStr):
 
     def match(self, value):
         return self.value==value
+
+
+class IP(UStr):
+    def __init__(self, value) -> None:
+        if not self.is_ip(value):
+            raise TypeError('Input parameter is not a ip')
+        super().__init__(value)
+
+    def is_private(self, ip)->bool:
+        return ip_address(ip).is_private
+
+    def is_ip(self, ip)->bool:
+        try:
+            ip_address(ip)
+            return True
+        except:
+            return False
+     
\ No newline at end of file
